
import { useState } from "react";
import { PhoneNumberList } from "./PhoneNumberList";
import { ConversationList } from "./ConversationList";
import { MessageComposer } from "./MessageComposer";
import {
  MessageSquare,
  Phone,
  Send,
  Menu,
} from "lucide-react";
import { Button } from "@/components/ui/button";

type PanelView = "numbers" | "conversations" | "compose";

export function Panel() {
  const [view, setView] = useState<PanelView>("numbers");
  const [isSidebarOpen, setIsSidebarOpen] = useState(true);

  const renderView = () => {
    switch (view) {
      case "numbers":
        return <PhoneNumberList />;
      case "conversations":
        return <ConversationList />;
      case "compose":
        return <MessageComposer />;
      default:
        return <PhoneNumberList />;
    }
  };

  return (
    <div className="flex h-screen bg-gray-50">
      {/* Sidebar */}
      <div
        className={`${
          isSidebarOpen ? "w-64" : "w-16"
        } bg-white border-r transition-all duration-300 ease-in-out flex flex-col`}
      >
        <div className="p-4 border-b flex justify-between items-center">
          <h1
            className={`font-semibold ${
              isSidebarOpen ? "opacity-100" : "opacity-0"
            } transition-opacity duration-300`}
          >
            Chatterbox
          </h1>
          <Button
            variant="ghost"
            size="icon"
            onClick={() => setIsSidebarOpen(!isSidebarOpen)}
            className="hover:bg-gray-100"
          >
            <Menu className="h-5 w-5" />
          </Button>
        </div>
        <nav className="flex-1 p-4">
          <div className="space-y-2">
            <Button
              variant={view === "numbers" ? "default" : "ghost"}
              className="w-full justify-start"
              onClick={() => setView("numbers")}
            >
              <Phone className="mr-2 h-4 w-4" />
              {isSidebarOpen && "Numbers"}
            </Button>
            <Button
              variant={view === "conversations" ? "default" : "ghost"}
              className="w-full justify-start"
              onClick={() => setView("conversations")}
            >
              <MessageSquare className="mr-2 h-4 w-4" />
              {isSidebarOpen && "Conversations"}
            </Button>
            <Button
              variant={view === "compose" ? "default" : "ghost"}
              className="w-full justify-start"
              onClick={() => setView("compose")}
            >
              <Send className="mr-2 h-4 w-4" />
              {isSidebarOpen && "New Message"}
            </Button>
          </div>
        </nav>
      </div>

      {/* Main Content */}
      <div className="flex-1 overflow-auto">
        <main className="max-w-4xl mx-auto">{renderView()}</main>
      </div>
    </div>
  );
}
